@@ -3,6 +3,7 @@ from .contexts import (
     QueryContext,
     TextContext,
     UpdateContext,
+    MessageContext,
 )
 from .handlers import (
     CommandHandler,
@@ -34,6 +35,8 @@ __all__ = [
     "InlineMenuHandler",
     "CommandsHandler",
     "UpdateContext",
+    "UpdateContext",
+    "MessageContext",
     "QueryContext",
     "TextContext",
 ]
