@@ -1,9 +1,9 @@
 from botty_core import Callback
 
-from .update import UpdateContext
+from .message import MessageContext
 
 
-class TextContext(UpdateContext):
+class TextContext(MessageContext):
     @property
     def text(self) -> str:
         return self.message.text
