@@ -1,9 +1,16 @@
-from botty import CompositeHandler, StartGroupHandler, StartHandler, TextContext, app
+from botty import (
+    CompositeHandler,
+    StartGroupHandler,
+    StartHandler,
+    TextContext,
+    app,
+    texts,
+)
 from botty.handlers import CommandHandler
 
 
 async def start_callback(ctx: TextContext) -> None:
-    await ctx.reply("start")
+    await ctx.reply(texts[1])
 
 
 async def start_group_callback(ctx: TextContext) -> None:
